@@ -6,6 +6,7 @@ import (
 
 	"github.com/stretchr/testify/require"
 
+	"github.com/pulumi/pulumi/pkg/v3/codegen"
 	"github.com/pulumi/pulumi/pkg/v3/codegen/internal/test"
 	"github.com/pulumi/pulumi/pkg/v3/testing/integration"
 	"github.com/pulumi/pulumi/sdk/v3/python"
@@ -14,16 +15,17 @@ import (
 var testdataPath = filepath.Join("..", "internal", "test", "testdata")
 
 func TestGenerateProgram(t *testing.T) {
-	test.TestProgramCodegen(t, test.ProgramLangConfig{
-		Language:   "python",
-		Extension:  "py",
-		OutputFile: "__main__.py",
-		Check:      pythonCheck,
-		GenProgram: GenerateProgram,
-	})
+	test.TestProgramCodegen(t,
+		test.ProgramCodegenOptions{
+			Language:   "python",
+			Extension:  "py",
+			OutputFile: "__main__.py",
+			Check:      pythonCheck,
+			GenProgram: GenerateProgram,
+		})
 }
 
-func pythonCheck(t *testing.T, path string) {
+func pythonCheck(t *testing.T, path string, _ codegen.StringSet) {
 	ex, _, err := python.CommandPath()
 	require.NoError(t, err)
 	name := filepath.Base(path)
